<?php declare(strict_types=1);

namespace Plugin\km_snackys\Migrations;

use JTL\Plugin\Migration;
use JTL\Update\IMigration;
use JTL\DB\ReturnType;
use JTL\Language\LanguageHelper;

class Migration20210917200000 extends Migration implements IMigration
{
	
	private $langVars = array(
		'hotStock' => array(
			'ger' => 'Nur noch %s verfügbar',
			'eng' => 'Only %s available'
		),
		'deliveryDate' => array(
			'ger' => 'Lieferdatum',
			'eng' => 'Deliverydate'
		),
		'COreg' => array(
			'ger' => 'Registrieren',
			'eng' => 'Register'
		),
		'COlogin' => array(
			'ger' => 'Anmelden',
			'eng' => 'Login'
		),
		'COguest' => array(
			'ger' => 'Als Gast bestellen',
			'eng' => 'Order as guest'
		),
		'menu' => array(
			'ger' => 'Menü',
			'eng' => 'Menu'
		),
		'allCats' => array(
			'ger' => 'Alle Kategorien',
			'eng' => 'All categories'
		),
		'language' => array(
			'ger' => 'Sprache',
			'eng' => 'Language'
		),
		'offlineTitle' => array(
			'ger' => 'Keine Internetverbindung',
			'eng' => 'No connection'
		),
		'offlineText' => array(
			'ger' => 'Sehr geehrter Besucher, scheinbar sind Sie nicht mit dem Internet verbunden.',
			'eng' => 'Dear visitor, it looks like you are not connected to the internet.'
		),
		'offlineButton' => array(
			'ger' => 'Neu laden',
			'eng' => 'Reload'
		),
		'configButton' => array(
			'ger' => '%s Komponenten konfigurieren',
			'eng' => 'configure %s components'
		),
		'configSet' => array(
			'ger' => 'Auswahl speichern',
			'eng' => 'Save selection'
		),
		'configRequiredInfo' => array(
			'ger' => 'Bitte schließen Sie zuerst Ihre Konfiguration ab',
			'eng' => 'Please complete your configuration first'
		),
		'loadPrev' => array(
			'ger' => 'vorherige laden',
			'eng' => 'load previous'
		),
		'loadNext' => array(
			'ger' => 'weitere laden',
			'eng' => 'load next'
		)
	);
	
    public function up()
    {					
		//Update Settings
		$css_ts_os_s = \Shop::Container()->getDB()->query('SELECT nValue,nKey FROM km_snackys_config WHERE nKey="css_ts_os_s"',1);
		if($css_ts_os_s->nValue == "20")
		{
			$css_ts_os_s->nValue = "10";
			\Shop::Container()->getDB()->queryPrepared(
				"UPDATE `km_snackys_config` SET `nValue`=:nValue WHERE `nKey`=:nKey",
				(array) $css_ts_os_s,
				ReturnType::DEFAULT
			);
		}
		$css_ts_os_b = \Shop::Container()->getDB()->query('SELECT nValue,nKey FROM km_snackys_config WHERE nKey="css_ts_os_b"',1);
		if($css_ts_os_b->nValue == "20")
		{
			$css_ts_os_b->nValue = "70";
			\Shop::Container()->getDB()->queryPrepared(
				"UPDATE `km_snackys_config` SET `nValue`=:nValue WHERE `nKey`=:nKey",
				(array) $css_ts_os_b,
				ReturnType::DEFAULT
			);
		}
		
		//New settings
		$this->execute("INSERT IGNORE INTO `km_snackys_config` SET `nKey`='dropdown_plus', `nValue`='0'");
		$this->execute("INSERT IGNORE INTO `km_snackys_config` SET `nKey`='show_topbar_mobile', `nValue`='0'");
		$this->execute("INSERT IGNORE INTO `km_snackys_config` SET `nKey`='gtagAllways', `nValue`='Y'");
		
		
		//Now check language variables
		$langHelper = new LanguageHelper(\Shop::Container()->getDB(), \Shop::Container()->getCache());
		$installedLanguages = $langHelper->getInstalled();

		$kSprachsektion = \Shop::Container()->getDB()
			->select(
				'tsprachsektion',
				'cName',
				'custom'
			)
			->kSprachsektion;
		foreach($installedLanguages as $lang)
		{
			$cISO = $lang->getCode();
			$langHelper->setzeSprache($cISO);
			foreach($this->langVars as $key => $valueVar)
			{
				$checkLang = $langHelper->get($key, 'custom');
				if(!$checkLang || (substr($checkLang,0,1)=='#' && substr($checkLang,-1,1)=='#'))
				{
					$value = ($cISO == 'ger') ? $valueVar['ger'] : $valueVar['eng'];
					$langHelper->fuegeEin($cISO, (int)$kSprachsektion, $key, $value);
				}
			}
		}
    }

    public function down()
    {
        //Nothing to Do
    }
}